syssvc

package
v0.0.0-...-8cdd30c Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 27, 2026 License: MIT Imports: 26 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Service

type Service struct {
	AwsApiClient *awsapi.Client
	S3Bucket     string

	SysUserStore sysuser.Store

	Logger *slog.Logger
}

func NewService

func NewService(awsApiClient *awsapi.Client, s3Bucket string, db *pgxpool.Pool, logger *slog.Logger) (svc Service)

func (Service) SelectUiStoreData

func (svc Service) SelectUiStoreData(ctx context.Context, db *pgxpool.Pool) (uiStoreData UiStoreData, err error)

func (Service) SetUserProfilePic

func (svc Service) SetUserProfilePic(ctx context.Context, userId int64, uploadFile lysformfile.UploadFile) (storedFileName string, err error)

SetUserProfilePic stores a user's profile picture as a JPEG in S3 and updates the user's record in the database with the stored file name. uploadFile must be a 400 px by 400 px gif, jpg, or png image file with a maximum size of 1 MB.

type UiStoreData

type UiStoreData struct {
	CoreMandatoryEnums []string `json:"core_mandatory_enums"`
	CoreOptionalEnums  []string `json:"core_optional_enums"`
	CorePeriods        []string `json:"core_periods"`

	DigmarkLauncherStati []string           `json:"digmark_launcher_stati"`
	DigmarkManagers      []string           `json:"digmark_managers"`
	DigmarkVerticals     []dmvertical.Model `json:"digmark_verticals"`

	EcbActiveCurrenciesExEur []ecbcurr.Model `json:"ecb_active_currencies_ex_eur"`

	GeoCountries []geocountry.Model `json:"geo_countries"`
	GeoOceans    []geoocean.Model   `json:"geo_oceans"`

	ProcessFlows []procflow.Model `json:"process_flows"`

	PubAuthors []pubauthor.Model `json:"pub_authors"`

	SuppCompanies         []suppcompany.Model      `json:"supp_companies"`
	SuppProductCategories []suppprodcategory.Model `json:"supp_product_categories"`
}

Jump to